BoundingBoxes

Struct BoundingBoxes 

pub struct BoundingBoxes { /* private fields */ }
A bounding box container for storing locations of detected objects

The bounding boxes are stored in xyxy format. Any input set of bounding boxes that has a box with a non-positive area will return an error.

Examples

use pineapple_core::im::BoundingBoxes;

let data: Vec<[f32; 4]> = vec![[0., 0., 1., 1.], [3., 4., 5., 7.]];
let boxes = BoundingBoxes::new(data);
assert!(boxes.is_ok());

let data: Vec<[f32; 4]> = vec![[2., 2., 1., 1.], [3., 4., 5., 7.]];
let boxes = BoundingBoxes::new(data);
assert!(boxes.is_err());

Implementations

Source

impl BoundingBoxes

pub fn new(data: Vec<[f32; 4]>) -> Result<Self, PineappleError>

Initialize a new bounding boxes container

Arguments
  • data - Bounding boxes in xyxy format
Examples
use pineapple_core::im::BoundingBoxes;

let data: Vec<[f32; 4]> = vec![[0., 0., 1., 1.], [3., 4., 5., 7.]];
let boxes = BoundingBoxes::new(data);
Source

impl BoundingBoxes

pub fn open<P: AsRef<Path>>(path: P) -> Result<BoundingBoxes, PineappleError>

Open bounding boxes from the provided path

Arguments
  • path - A path to bounding boxes with a valid extension
Examples
use pineapple_core::im::BoundingBoxes;
let bounding_boxes = BoundingBoxes::open("boxes.json");
pub fn save<P: AsRef<Path>>(&self, path: P) -> Result<(), PineappleError>

Save bounding boxes at the provided path

Arguments
  • path - Path to save bounding boxes
Examples
use pineapple_core::im::BoundingBoxes;
let boxes = BoundingBoxes::open("boxes.json").unwrap();
boxes.save("boxes.json").unwrap();
Source

impl BoundingBoxes

pub fn len(&self) -> usize

Number of bounding boxes

pub fn is_empty(&self) -> bool

Check if bounding boxes are empty

Source

impl BoundingBoxes

pub fn as_xyxy(&self) -> &Vec<[f32; 4]>

Return a reference to underlying bounding boxes data

pub fn to_xyxy(self) -> Vec<[f32; 4]>

Return the underlying bounding boxes data

pub fn to_xywh(self) -> Vec<[f32; 4]>

Return the bounding box data in xywh format

Source

impl BoundingBoxes

pub fn remove(&mut self, indices: &[usize])

Remove bounding boxes based on an array of pre-sorted (ascending) indices