PineappleViewBuffer

Struct PineappleViewBuffer 

pub struct PineappleViewBuffer<'a, T, Container> { /* private fields */ }
A row-major buffer that defines an image view/crop/subregion

The cropped object represents a zero-copy reference to a larger PineappleBuffer. To enable zero-copy, the full image has to share the same lifetime as the cropped object. This should generally always be the case since we perform operations on cropped objects iteratively across all segmented objects from the same image.

Examples

use pineapple_core::im::{PineappleBuffer, PineappleViewBuffer};

let width = 3;
let height = 3;
let channels = 1;
let data = vec![0, 1, 2, 3, 4, 5, 6, 7, 8];

let buffer = PineappleBuffer::<u8, Vec<u8>>::new(width, height, channels, data).unwrap();
let crop = PineappleViewBuffer::new(1, 1, 2, 2, &buffer);

for subpixel in crop.iter() {
    let _ = subpixel;
}

Implementations

Source

impl<'a> PineappleViewBuffer<'a, u32, Vec<u32>>

pub fn save<P: AsRef<Path>>( &'a self, path: P, label: &u32, ) -> Result<(), PineappleError>

Save an object

Arguments
  • path - A path to an image with a valid extension
use pineapple_core::im::PineappleImage;
let image = PineappleImage::open("image.png");
Source

impl<'a, T, Container> PineappleViewBuffer<'a, T, Container>
where T: ToPrimitive + FromPrimitive, Container: Deref<Target = [T]>,

pub fn new( x: u32, y: u32, w: u32, h: u32, buffer: &'a PineappleBuffer<T, Container>, ) -> Self

Initialize a copy-free object specifying a cropped/subregion of an image

Examples
use pineapple_core::im::{PineappleBuffer, PineappleViewBuffer};

let width = 3;
let height = 3;
let channels = 1;
let data: Vec<u8> = vec![0, 1, 2, 3, 4, 5, 6, 7, 8];

let buffer = PineappleBuffer::<u8, Vec<u8>>::new(width, height, channels, data).unwrap();
let crop = PineappleViewBuffer::new(1, 1, 2, 2, &buffer);
Source

impl<T, Container> PineappleViewBuffer<'_, T, Container>
where T: ToPrimitive + FromPrimitive, Container: Deref<Target = [T]>,

pub fn len(&self) -> usize

Length of cropped buffer

pub fn is_empty(&self) -> bool

Check if buffer is empty

pub fn width(&self) -> usize

Width of object

pub fn height(&self) -> usize

Height of object

pub fn channels(&self) -> usize

Number of channels

Source

impl<'a, T, Container> PineappleViewBuffer<'a, T, Container>
where T: ToPrimitive + FromPrimitive, Container: Deref<Target = [T]>,

pub fn intensity(&'a self) -> [f32; 7]

Compute the intensity descriptors for the object

pub fn moments(&'a self) -> [f32; 24]

Compute the image moments for the object

pub fn texture(&'a self) -> [f32; 13]

Compute the texture descriptors for the object

pub fn zernike(&'a self) -> [f32; 30]

Compute the zernike moments for the object

pub fn descriptors(&'a self) -> Vec<f32>

Compute all view descriptors

Source

impl<'a, T, Container> PineappleViewBuffer<'a, T, Container>
where T: ToPrimitive + FromPrimitive, Container: Deref<Target = [T]>,

pub fn iter(&'a self) -> SubpixelIterator<'a, T, Container>

Return an iterator over pixels containing all channels

pub fn iter_pixels(&'a self) -> PixelIterator<'a, T, Container>

Return an iterator over pixels containing all channels