Polygons

Struct Polygons 

pub struct Polygons { /* private fields */ }
A polygon container for storing object outlines

The polygons are stored in (N, 2, K) format where N is the number of polygons for a given mask/image, 2 is xy, and K specifies the number of points in each polygon. Note that the polygons can be ragged so K can vary for each polygon.

Examples

use pineapple_core::im::Polygons;

let data: Vec<Vec<[f32; 2]>> = vec![
    vec![[0., 1.], [1., 1.], [1., 2.], [0., 2.]],
    vec![[1., 1.], [2., 1.], [2., 2.], [1., 2.]],
];

let polygons = Polygons::new(data);
assert!(polygons.is_ok());

let data: Vec<Vec<[f32; 2]>> = vec![
    vec![[0., 1.], [1., 1.]],
    vec![[1., 1.], [2., 1.]],
];

let polygons = Polygons::new(data);
assert!(polygons.is_err());

Implementations

Source

impl Polygons

pub fn new(data: Vec<Vec<[f32; 2]>>) -> Result<Self, PineappleError>

Initialize a new polygons container

Arguments
  • data - Polygons in (N, 2, K) format
Examples
use pineapple_core::im::Polygons;

let data: Vec<Vec<[f32; 2]>> = vec![
    vec![[0., 1.], [1., 1.], [1., 2.]],
    vec![[1., 1.], [2., 1.], [2., 2.]],
];

let polygons = Polygons::new(data);
Source

impl Polygons

pub fn open<P: AsRef<Path>>(path: P) -> Result<Polygons, PineappleError>

Open polygons from the provided path

Arguments
  • path - A path to polygons with a valid extension
Examples
use pineapple_core::im::Polygons;
let polygons = Polygons::open("polygons.json");
pub fn save<P: AsRef<Path>>(&self, path: P) -> Result<(), PineappleError>

Save a polygons at the provided paath

Arguments
  • path - Path to save polygons
Examples
use pineapple_core::im::Polygons;
let polygons = Polygons::open("polygons.json").unwrap();
polygons.save("polygons.json").unwrap();
Source

impl Polygons

pub fn len(&self) -> usize

Return the number of stored polygons

pub fn is_empty(&self) -> bool

Check if polygon has no data

Source

impl Polygons

pub fn as_points(&self) -> &Vec<Vec<[f32; 2]>>

Return a reference to the underlying polygon point

pub fn to_points(self) -> Vec<Vec<[f32; 2]>>

Return the underlying polygon point

pub fn to_bounding_boxes(&self) -> Result<BoundingBoxes, PineappleError>

Convert the polygons to bounding boxes

Source

impl Polygons

pub fn dedup_points(&mut self)

Deduplicate redundant points in each polygon

pub fn order_points(&mut self)

Order the points in each polygon

pub fn resample_points(&mut self, n: usize)

Resample each polygon to an equal number of equidistant points

pub fn remove(&mut self, indices: &[usize])

Remove polygons based on an array of pre-sorted (ascending) indices

pub fn descriptors(&mut self) -> Vec<[f32; 23]>

Compute morphological measurements from polygons