Functions
- write_
embeddings_ npz - Write neural network single object embeddings to a .npz file
- write_
numpy - Write a numpy file from a vector of specified shape
- write_
table - Write a DataFrame to disk
- write_
table_ csv - Write a table to a CSV file
- write_
table_ pq - Write a table to a parquet file
- write_
table_ tsv - Write a table to a TSV file