Module path

Module path 

Functions

collect_file_pairs
Collect file pairs that share matching prefix
collect_file_paths
Collect file paths from a directory with an optional substring filter
create_directory
Ensures a new directory is created with an incrementing suffix if necessary.