pub struct BoundingBoxes { /* private fields */ }Expand description
A bounding box container for storing locations of detected objects
The bounding boxes are stored in xyxy format. Any input set of bounding boxes that has a box with a non-positive area will return an error.
Examples
use pineapple_core::im::BoundingBoxes;
let data: Vec<[f32; 4]> = vec![[0., 0., 1., 1.], [3., 4., 5., 7.]];
let boxes = BoundingBoxes::new(data);
assert!(boxes.is_ok());
let data: Vec<[f32; 4]> = vec![[2., 2., 1., 1.], [3., 4., 5., 7.]];
let boxes = BoundingBoxes::new(data);
assert!(boxes.is_err());Implementations
Sourceimpl BoundingBoxes
impl BoundingBoxes
Sourceimpl BoundingBoxes
impl BoundingBoxes
Sourcepub fn open<P: AsRef<Path>>(path: P) -> Result<BoundingBoxes, PineappleError>
pub fn open<P: AsRef<Path>>(path: P) -> Result<BoundingBoxes, PineappleError>
Sourceimpl BoundingBoxes
impl BoundingBoxes
Sourceimpl BoundingBoxes
impl BoundingBoxes