pub struct PineappleViewBuffer<'a, T, Container> { /* private fields */ }Expand description
A row-major buffer that defines an image view/crop/subregion
The cropped object represents a zero-copy reference to a larger PineappleBuffer. To enable zero-copy, the full image has to share the same lifetime as the cropped object. This should generally always be the case since we perform operations on cropped objects iteratively across all segmented objects from the same image.
Examples
use pineapple_core::im::{PineappleBuffer, PineappleViewBuffer};
let width = 3;
let height = 3;
let channels = 1;
let data = vec![0, 1, 2, 3, 4, 5, 6, 7, 8];
let buffer = PineappleBuffer::<u8, Vec<u8>>::new(width, height, channels, data).unwrap();
let crop = PineappleViewBuffer::new(1, 1, 2, 2, &buffer);
for subpixel in crop.iter() {
let _ = subpixel;
}Implementations
Sourceimpl<'a, T, Container> PineappleViewBuffer<'a, T, Container>
impl<'a, T, Container> PineappleViewBuffer<'a, T, Container>
Sourcepub fn new(
x: u32,
y: u32,
w: u32,
h: u32,
buffer: &'a PineappleBuffer<T, Container>,
) -> Self
pub fn new( x: u32, y: u32, w: u32, h: u32, buffer: &'a PineappleBuffer<T, Container>, ) -> Self
Initialize a copy-free object specifying a cropped/subregion of an image
Examples
use pineapple_core::im::{PineappleBuffer, PineappleViewBuffer};
let width = 3;
let height = 3;
let channels = 1;
let data: Vec<u8> = vec![0, 1, 2, 3, 4, 5, 6, 7, 8];
let buffer = PineappleBuffer::<u8, Vec<u8>>::new(width, height, channels, data).unwrap();
let crop = PineappleViewBuffer::new(1, 1, 2, 2, &buffer);Sourceimpl<T, Container> PineappleViewBuffer<'_, T, Container>
impl<T, Container> PineappleViewBuffer<'_, T, Container>
Sourceimpl<'a, T, Container> PineappleViewBuffer<'a, T, Container>
impl<'a, T, Container> PineappleViewBuffer<'a, T, Container>
Sourcepub fn descriptors(&'a self) -> Vec<f32>
pub fn descriptors(&'a self) -> Vec<f32>
Compute all view descriptors
Sourceimpl<'a, T, Container> PineappleViewBuffer<'a, T, Container>
impl<'a, T, Container> PineappleViewBuffer<'a, T, Container>
Sourcepub fn iter(&'a self) -> SubpixelIterator<'a, T, Container>
pub fn iter(&'a self) -> SubpixelIterator<'a, T, Container>
Return an iterator over pixels containing all channels
Sourcepub fn iter_pixels(&'a self) -> PixelIterator<'a, T, Container>
pub fn iter_pixels(&'a self) -> PixelIterator<'a, T, Container>
Return an iterator over pixels containing all channels