pub struct Polygons { /* private fields */ }Expand description
A polygon container for storing object outlines
The polygons are stored in (N, 2, K) format where N is the number of polygons for a given mask/image, 2 is xy, and K specifies the number of points in each polygon. Note that the polygons can be ragged so K can vary for each polygon.
Examples
use pineapple_core::im::Polygons;
let data: Vec<Vec<[f32; 2]>> = vec![
vec![[0., 1.], [1., 1.], [1., 2.], [0., 2.]],
vec![[1., 1.], [2., 1.], [2., 2.], [1., 2.]],
];
let polygons = Polygons::new(data);
assert!(polygons.is_ok());
let data: Vec<Vec<[f32; 2]>> = vec![
vec![[0., 1.], [1., 1.]],
vec![[1., 1.], [2., 1.]],
];
let polygons = Polygons::new(data);
assert!(polygons.is_err());Implementations
Sourceimpl Polygons
impl Polygons
Sourcepub fn as_points(&self) -> &Vec<Vec<[f32; 2]>>
pub fn as_points(&self) -> &Vec<Vec<[f32; 2]>>
Return a reference to the underlying polygon point
Sourcepub fn to_bounding_boxes(&self) -> Result<BoundingBoxes, PineappleError>
pub fn to_bounding_boxes(&self) -> Result<BoundingBoxes, PineappleError>
Convert the polygons to bounding boxes
Sourceimpl Polygons
impl Polygons
Sourcepub fn dedup_points(&mut self)
pub fn dedup_points(&mut self)
Deduplicate redundant points in each polygon
Sourcepub fn order_points(&mut self)
pub fn order_points(&mut self)
Order the points in each polygon
Sourcepub fn resample_points(&mut self, n: usize)
pub fn resample_points(&mut self, n: usize)
Resample each polygon to an equal number of equidistant points
Sourcepub fn remove(&mut self, indices: &[usize])
pub fn remove(&mut self, indices: &[usize])
Remove polygons based on an array of pre-sorted (ascending) indices
Sourcepub fn descriptors(&mut self) -> Vec<[f32; 23]>
pub fn descriptors(&mut self) -> Vec<[f32; 23]>
Compute morphological measurements from polygons