Module io

Module io 

Functions

write_embeddings_npz
Write neural network single object embeddings to a .npz file
write_numpy
Write a numpy file from a vector of specified shape
write_table
Write a DataFrame to disk
write_table_csv
Write a table to a CSV file
write_table_pq
Write a table to a parquet file
write_table_tsv
Write a table to a TSV file