Functions
- collect_
file_ pairs - Collect file pairs that share matching prefix
- collect_
file_ paths - Collect file paths from a directory with an optional substring filter
- create_
directory - Ensures a new directory is created with an incrementing suffix if necessary.